@@ -1,6 +1,6 @@
 import configparser
 from pathlib import Path
-
+from os import path as ospath
 import typer
 import yaml_env_var_parser as yaml
 from dotenv import load_dotenv
@@ -24,6 +24,7 @@ class Configurations:
 
     scripts = dict()
     services = []
+    volumes = dict()
     _companion_file = ""
     _compose_file = ""
 
@@ -37,6 +38,9 @@ class Configurations:
 
         return cls._instance
 
+    def _resolve_path(value):
+        return Path(ospath.expandvars(value.replace('~', '$HOME'))).resolve()
+
     def _save(self):
         with open(self.config_file, "w") as file:
             self.config_parser.write(file)
@@ -62,7 +66,7 @@ class Configurations:
         if not value:
             self._companion_file = ""
         else:
-            self._companion_file = f"{Path(value).resolve()}"
+            self._companion_file = f"{self._resolve_path(value)}"
         self.set_config("companion_file", self._companion_file)
 
     @property
@@ -79,7 +83,7 @@ class Configurations:
         if not value:
             self._compose_file = ""
         else:
-            self._compose_file = f"{Path(value).resolve()}"
+            self._compose_file = f"{self._resolve_path(value)}"
         self.set_config("compose_file", self._compose_file)
 
     def _load_config_file(self):
@@ -90,9 +94,13 @@ class Configurations:
             self._save()
 
     def _request_compose_file(self):
-        local_compose_file = Path("docker-compose.yaml").resolve()
+        local_compose_file_yaml = Path("docker-compose.yaml").resolve()
+        local_compose_file_yml = Path("docker-compose.yml").resolve()
 
-        if local_compose_file.is_file():
+        if local_compose_file_yaml.is_file():
+            self.compose_file = str(local_compose_file)
+            return
+        elif local_compose_file_yml.is_file():
             self.compose_file = str(local_compose_file)
             return
 
@@ -100,7 +108,7 @@ class Configurations:
             "Please informe the path to your docker compose file (including filename)"
         )
 
-        compose_file_path = Path(compose_file_input).resolve()
+        compose_file_path = self._resolve_path(compose_file_input)
         if not compose_file_path.is_file():
             err_console.print("The informed path is invalid.\n")
             return
@@ -109,9 +117,13 @@ class Configurations:
         print("Your file path has been saved!\n")
 
     def _request_companion_file(self):
-        local_companion_file = Path("compose-companion.yaml").resolve()
+        local_companion_file_yaml = Path("compose-companion.yaml").resolve()
+        local_companion_file_yml = Path("compose-companion.yml").resolve()
 
-        if local_companion_file.is_file():
+        if local_companion_file_yaml.is_file():
+            self.companion_file = str(local_companion_file)
+            return
+        if local_companion_file_yml.is_file():
             self.companion_file = str(local_companion_file)
             return
         elif Path(self.compose_file).is_file():
@@ -126,7 +138,7 @@ class Configurations:
             "Please informe the path to your companion scripts file (including filename)"
         )
 
-        companion_file_path = Path(companion_file_input).resolve()
+        companion_file_path = self._resolve_path(companion_file_input)
         if not companion_file_path.is_file():
             err_console.print("The informed path is invalid.\n")
             return
@@ -146,9 +158,23 @@ class Configurations:
 
         try:
             with open(self.compose_file, "r") as file:
-                parsed = yaml.load(file)
+                parsed = yaml.load(file)                
                 if parsed:
-                    self.services = list(dict(parsed)["services"].keys())
+                    services_dict = dict(parsed).get("services", {})
+                    volumes_dict = dict(parsed).get("volumes", {})
+
+                self.services = list(services_dict.keys())
+                for service_name in self.services:
+                    self.volumes[service_name] = []
+
+                volumes_list = list(volumes_dict.keys())
+                for key, value in services_dict.items():
+                    service_vols = value.get("volumes", [])
+                    for service_vol in service_vols:
+                        if service_vol.split(":")[0] in volumes_list:
+                            self.volumes[key].append({'host': service_vol.split(":")[0], 'container': service_vol.split(":")[1]})
+
+                
         except (FileNotFoundError, IsADirectoryError) as err:
             err_console.print("Docker Compose file path is invalid")
             self.compose_file = ""
